 > **NOTE: This is an active fork of clayrisser/sphinx-markdown-builder.**

# sphinxnotes-markdown-builder

[![PyPI](https://img.shields.io/pypi/v/sphinxnotes-markdown-builder.svg?style=flat-square)](https://pypi.org/project/sphinxnotes-markdown-builder)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/sphinxnotes-markdown-builder.svg?style=flat-square)](https://pypi.org/project/sphinxnotes-markdown-builder)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sphinxnotes-markdown-builder.svg?style=flat-square)](https://pypi.org/project/sphinxnotes-markdown-builder)
[![GitHub stars](https://img.shields.io/github/stars/sphinx-notes/markdown-builder.svg?style=flat-square&label=Stars)](https://github.com/sphinx-notes/markdown-builder)

> sphinx builder that outputs markdown files

Please ★ this repo if you found it useful ★ ★ ★

If you want frontmatter support please use [sphinx-jekyll-builder](https://github.com/codejamninja/sphinx-jekyll-builder)


## Built by Silicon Hills LLC

[![index](https://user-images.githubusercontent.com/6234038/71054254-f284ad80-2116-11ea-9013-d68306726854.jpeg)](https://nuevesolutions.com)

Silicon Hills offers premium Node and React develpoment and support services. Get in touch at [nuevesolutions.com](https://nuevesolutions.com).


## Recommended Projects

* [sphinx-markdown-parser](https://github.com/codejamninja/sphinx-markdown-parser) - write markdown inside of docutils & sphinx projects


## Features

* Generates markdown


## Installation

```sh
pip3 install sphinxnotes-markdown-builder
```


## Dependencies

* [Python 3](https://www.python.org)


## Usage

Build markdown files with Makefile

```sh
make markdown
```

Build markdown files with `sphinx-build` command

```sh
cd docs
sphinx-build -M markdown ./ build
```


## Support

Submit an [issue](https://github.com/sphinx-notes/markdown-builder/issues/new)


## Screenshots

[Contribute](https://github.com/sphinx-notes/markdown-builder/blob/master/CONTRIBUTING.md) a screenshot


## Contributing

Review the [guidelines for contributing](https://github.com/sphinx-notes/markdown-builder/blob/master/CONTRIBUTING.md)


## License

[MIT License](https://github.com/sphinx-notes/markdown-builder/blob/master/LICENSE)

[Jam Risser](https://codejam.ninja) © 2018


## Changelog

Review the [changelog](https://github.com/sphinx-notes/markdown-builder/blob/master/CHANGELOG.md)


## Credits

* [Jam Risser](https://codejam.ninja) - Author
* [Matthew Brett](https://github.com/matthew-brett/nb2plots/blob/master/nb2plots/doctree2md.py) - doctree2md
* [Shengyu Zhang](https://silverrainz.me) - Current maintainer
